@@ -2,17 +2,17 @@ import logging
 from ipaddress import IPv6Address
 from pathlib import Path
 
-from pycaracal import Probe, log_to_stderr, prober, set_log_level
+from pycaracal import Probe, log_to_stderr, prober, set_log_format, set_log_level
 
 
 def test_probe():
-    p1 = Probe("8.8.4.4", 24000, 33434, 32, "udp")
-    p2 = Probe("::ffff:8.8.4.4", 24000, 33434, 32, "udp")
-    p3 = Probe("::ffff:8.8.4.4", 24000, 33434, 32, "icmp")
-    p4 = Probe(int(IPv6Address("::ffff:8.8.4.4")), 24000, 33434, 32, "icmp")
+    p1 = Probe("8.8.4.4", 24000, 33434, 32, "udp", 0)
+    p2 = Probe("::ffff:8.8.4.4", 24000, 33434, 32, "udp", 0)
+    p3 = Probe("::ffff:8.8.4.4", 24000, 33434, 32, "icmp", 0)
+    p4 = Probe(int(IPv6Address("::ffff:8.8.4.4")), 24000, 33434, 32, "icmp", 0)
     assert (
         str(p1)
-        == "Probe(dst_addr=8.8.4.4 src_port=24000 dst_port=33434 ttl=32 protocol=udp)"
+        == "Probe(dst_addr=8.8.4.4 src_port=24000 dst_port=33434 ttl=32 protocol=udp wait_ms=0)"
     )
     assert p1 == p2
     assert p2 != p3
@@ -28,13 +28,14 @@ def test_prober():
     config.set_output_file_csv("zzz_output.csv")
     config.set_sniffer_wait_time(1)
     probes = [
-        Probe("8.8.4.4", 24000, 33434, 32, "icmp"),
-        Probe("8.8.4.4", 24000, 33434, 32, "udp"),
-        Probe("8.8.8.8", 24000, 33434, 32, "icmp"),
-        Probe("8.8.8.8", 24000, 33434, 32, "udp"),
+        Probe("8.8.4.4", 24000, 33434, 32, "icmp", 0),
+        Probe("8.8.4.4", 24000, 33434, 32, "udp", 0),
+        Probe("8.8.8.8", 24000, 33434, 32, "icmp", 0),
+        Probe("8.8.8.8", 24000, 33434, 32, "udp", 0),
     ]
     log_to_stderr()
     set_log_level(logging.DEBUG)
+    set_log_format("[%Y-%m-%d %H:%M:%S.%e] [%l] [caracal] %v")
     prober_stats, sniffer_stats, pcap_stats = prober.probe(config, [])
     assert prober_stats.read == 0
     assert pcap_stats.received >= sniffer_stats.received_count
