@@ -1,5 +1,5 @@
 #include <caracal/pretty.hpp>
-#include <catch2/catch_test_macros.hpp>
+#include <catch2/catch.hpp>
 #include <sstream>
 #include <string>
 
